# Coding Test Input Generator

## Usage
```
python -m cotegen run random --filename <filename>

python -m cotegen run mutation --filename <filename> --show-survived <true or false>

python -m cotegen run kill --filename <filename> --mutation-fitness <true or false>
```